==> db4o-5.0-mono.tar.gz: db4o-5.0/src/test/src/com/db4o/test/net2/Net2QueryForClass.cs <==
/* Copyright (C) 2004 - 2005  db4objects Inc.  http://www.db4o.com

This file is part of the db4o open source object database.

db4o is free software; you can redistribute it and/or modify it under
the terms of version 2 of the GNU General Public License as published
by the Free Software Foundation and as clarified by db4objects' GPL 
interpretation policy, available at
http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
Suite 350, San Mateo, CA 94403, USA.

db4o is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or
FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
for more details.

You should have received a copy of the GNU General Public License along
with this program; if not, write to the Free Software Foundation, Inc.,
59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
namespace com.db4o.test.net2
{
#if NET_2_0
    using System;
    using System.Collections.Generic;
    using System.Text;
    using com.db4o;
    using com.db4o.test;
    using com.db4o.query;

    public class Net2QueryForClass
    {
        public string _name;

        public Net2QueryForClass()
        {

        }

        public Net2QueryForClass(string name)
        {
            _name = name;
        }

        public void storeOne()
        {
            _name = "one";
        }

        public void test(){
            ObjectContainer oc = Tester.objectContainer();
            IList <Net2QueryForClass> list = oc.query<Net2QueryForClass>(typeof(Net2QueryForClass));
            foreach (Net2QueryForClass res in list)
            {
                Tester.ensure(res._name.Equals("one"));
            }
    }






    }
#endif
}

==> db4o-5.5-mono.tar.gz: db4o-5.5/src/test/src/com/db4o/test/net2/Net2QueryForClass.cs <==
/* Copyright (C) 2004 - 2006  db4objects Inc.  http://www.db4o.com

This file is part of the db4o open source object database.

db4o is free software; you can redistribute it and/or modify it under
the terms of version 2 of the GNU General Public License as published
by the Free Software Foundation and as clarified by db4objects' GPL 
interpretation policy, available at
http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
Suite 350, San Mateo, CA 94403, USA.

db4o is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or
FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
for more details.

You should have received a copy of the GNU General Public License along
with this program; if not, write to the Free Software Foundation, Inc.,
59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
namespace com.db4o.test.net2
{
#if NET_2_0 || CF_2_0
    using System;
    using System.Collections.Generic;
    using System.Text;
    using com.db4o;
    using com.db4o.test;
    using com.db4o.query;

    public class Net2QueryForClass
    {
        public string _name;

        public Net2QueryForClass()
        {

        }

        public Net2QueryForClass(string name)
        {
            _name = name;
        }

        public void StoreOne()
        {
            _name = "one";
        }

        public void Test(){
            ObjectContainer oc = Tester.ObjectContainer();
            IList <Net2QueryForClass> list = oc.Query<Net2QueryForClass>(typeof(Net2QueryForClass));
            foreach (Net2QueryForClass res in list)
            {
                Tester.Ensure(res._name.Equals("one"));
            }
    }






    }
#endif
}
